yakumo.cinder.v2.qos.Resource

Package yakumo :: Package cinder :: Package v2 :: Module qos :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

resource class for QoS specifications on Block Storage V2 API

Instance Methods | [hide private]
dict |
get_metadata(self) Aquire specs of a QoS Specs | source code
None |
set_metadata(self, **kwargs) Add or update specs into a QoS specification | source code
None |
unset_metadata(self, *keys) Remove specs from a QoS specification | source code
[yakumo.cinder.v2.volume_types.Resource] |
get_associations(self) Get associated volume types for a QoS specs | source code
None |
associate(self, *volume_types) Associate QoS specs with a volume type | source code
None |
disassociate(self, *volume_types) Dissociate QoS specs from a volume type | source code
None |
disassociate_all(self) Disassociate QoS specs from all associations | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `update`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _stable_state = ``[``'``available``'``,` `'``error``'``,` `'``error_deleting``'``]``
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get_metadata(self) | source code
Aquire specs of a QoS Specs Returns: dict specs in key=value format

### set_metadata(self, **kwargs) | source code
Add or update specs into a QoS specification name can't be altered. Parameters: `kwargs` (str=str) - key=value style specs Returns: None

### unset_metadata(self, *keys) | source code
Remove specs from a QoS specification Parameters: `keys` ([str]) - List of keys to be deleted Returns: None

### get_associations(self) | source code
Get associated volume types for a QoS specs Returns: [yakumo.cinder.v2.volume_types.Resource] List of associated volume types

### associate(self, *volume_types) | source code
Associate QoS specs with a volume type Parameters: `volume_type` ([yakumo.cinder.v2.volume_type.Resource]) - Volume type to be associated Returns: None

### disassociate(self, *volume_types) | source code
Dissociate QoS specs from a volume type Parameters: `volume_type` (yakumo.cinder.v2.volume_type.Resource) - Volume type to be dissociated Returns: None